@@ -24,10 +24,12 @@ class BuilderApt(OneSourceOneTarget):
         args = []
         if ConfigSudo.sudo:
             args.append("sudo")
+        # Here is how to keep apt-get quiet:
+        # https://stackoverflow.com/questions/52642097/apt-get-with-quiet-option-is-still-noisy
         args.extend([
             'apt-get',
+            '-q=2',
             '--yes',
-            '--quiet',
             'install',
         ])
         args.extend(self.packages)
